@@ -11,9 +11,12 @@ from .routers import (
     ExactRouterX0Y0N,
 )
 from .pair import CarbonPair
+from .carbon_order_ui import CarbonOrderUI
 from .simulators import CarbonSimulatorUI
 from .simulators import sim_analytics as analytics
 
+P = CarbonPair
+
+__version__ = "2.0"
+__date__ = "14/Dec/2022"
 
-__version__ = "1.4"
-__date__ = "6/Dec/2022"
