@@ -3,9 +3,13 @@ wrapper UI class for the Carbon simulation
 
 (c) Copyright Bprotocol foundation 2022. 
 Licensed under MIT
+
+VERSION HISTORY
+v2.0 - require slashpair notation (breaking change); exclude_future, constants for matching method
+v2.2 - curve disabling, single orders
 """
-__version__ = "1.0"
-__date__ = "21/Nov/2022"
+__version__ = "2.2"
+__date__ = "8/Dec/2022"
 
 import itertools
 from typing import Callable, Any, Tuple, Dict, List
@@ -27,39 +31,51 @@ class CarbonSimulatorUI:
 
     :verbose:           if True (default), the simulation logger. infos out info along the way
     :pair:              if given, Simulation methods uses this pair as default; other pairs
-                        can still be used, but need to be explicitly mentioned
+                        can still be used, but need to be explicitly mentioned; pairs must be provided 
+                        either as CarbonPair, or in the slash format "ETH/USDC"
     :raiseonerror:      if False (default), errors are caught and returned to the result dict
-    :matching_method:   if "exact" (default), the exact matching algorithm is used; otherwise the "fast" algorithm
+    :matching_method:   if MATCH_EXCACT (default), the exact matching algorithm is used; otherwise 
+                        choices are MATCH_FAST and MATCH_ALPHA
     :decimals:          the number of decimals to which the output is rounded
+    :exclude_future:    if True (default), excludes future and experimental features
     """
 
+    __VERSION__ = __version__
+    __DATE__    = __date__
+
+    MATCH_EXACT = "exact"
+    MATCH_FAST = "fast_"
+    MATCH_ALPHA = "alpha_"
+
     def __init__(
             self,
             verbose: bool = False,
             pair: Any = None,
             raiseonerror: bool = False,
             decimals: int = 6,
-            matching_method: str = "exact",
+            matching_method: str = MATCH_EXACT,
+            exclude_future: bool = True,
     ):
         self._pos_id = itertools.count()
         self.verbose = verbose
         self.debug = False  # setting this to True enables debug output
+        self.exclude_future = exclude_future
 
-        if isinstance(pair, CarbonPair):
-            # print("[__init__] CarbonPair provided", pair)
-            self.pair = pair.pair_iso
-            self._carbon_pair = pair
-        else:
-            self.pair = pair
-            self._carbon_pair = None
+        self._carbon_pair = CarbonPair.create(pair)
 
         self.raiseonerror = raiseonerror
         self.numtrades = 0
         self.decimals = decimals
-        self.matcher = (
-            AlphaRouter(verbose=False) if matching_method == 'alpha'
-            else ExactRouterX0Y0N(verbose=False)
-        )
+        self._mm = matching_method
+        if matching_method == self.MATCH_ALPHA:
+            self.matcher = AlphaRouter(verbose=False)
+        elif matching_method == self.MATCH_EXACT:
+            self.matcher = ExactRouterX0Y0N(verbose=False)
+        elif matching_method == self.MATCH_FAST:
+            raise ValueError("Fast router not implemented", matching_method)
+        else:
+            raise ValueError("Illegal value for matching_method", matching_method)
+
         self.orders = {}
         self.vault = {}
         self.trades = {}
@@ -69,6 +85,23 @@ class CarbonSimulatorUI:
                 f"[__init__] pair={pair}, verbose={verbose}, raiseonerror={raiseonerror}"
             )
 
+    class ExcludedFutureFunctionality(ValueError):
+        """
+        exception raised when functionality requested is considered future, and `excludefuture` is True
+        """
+        pass
+
+    def _raise_if_future_restricted(self, msg=None, *args, **kwargs):
+        """
+        raises ExcludedFutureFunctionality exception if self.exclude_future is True
+
+        :msg, args, kwargs:     arguments for the exception
+        """
+        if self.exclude_future:
+            if msg is None:
+                msg = "Feature disabled (us `exclude_future = False` to enable)"
+            raise self.ExcludedFutureFunctionality(msg, *args, **kwargs)
+
     @property
     def default_basetoken(self):
         """
@@ -87,51 +120,44 @@ class CarbonSimulatorUI:
 
     tknq = default_quotetoken
 
-    def get_carbon_pair(self, pair: str = None, tkn: str = None) -> Tuple[CarbonPair, str]:
+    def get_carbon_pair(self, pair = None):
         """
         helper functon determining the pair from function params and class defaults
 
-        :pair:      a string determining the pair, or CarbonPair (which is simply returned)
-        :tkn:       one token that is part of the pair
-        :returns:   CarbonPairStatic object, or raises
+        :pair:      a slashpair-formt string determining the pair, or CarbonPair
+        :returns:   CarbonPair object, or raises
         """
-        if isinstance(pair, CarbonPair):
-            return pair
+        if pair:
+            return CarbonPair.create(pair)
 
-        if pair is None:
-            if self._carbon_pair:
-                # no pair is given here, we have a carbon pair in the defaults -> that's it
-                return self._carbon_pair
-            pair = self.pair
+        if self._carbon_pair is None:
+            raise ValueError("Pair must be provided in function or simulation defaults")
 
-        if pair is None:
-            raise ValueError(
-                "Trading pair must be provided either in function call or in simulation defaults"
-            )
-        return CarbonPair.from_isopair_and_tkn(pair, tkn)
+        return self._carbon_pair
 
     @property
     def carbon_pair(self):
         """return the default CarbonPair associated with this object, or None"""
-        try:
-            cp = self.get_carbon_pair()
-            return cp
-        except:
-            return None
+        return self._carbon_pair
 
-    def price_convention(self, pair, tkn):
+    @property
+    def slashpair(self):
+        """return the slashpair or None"""
+        return self._carbon_pair.slashpair if self._carbon_pair else None
+
+    def price_convention(self, pair=None):
         """
         gets the price convention associated with `pair`
 
-        :pair:      a string describing the pair (eg, "ETHUSDC")
-        :tkn:       any constituent token of pair; required to split the pair into its
-                    token parts; no other semantic meaning
+        :pair:      a string describing the pair (eg, "ETH/USDC"); if None (default)
+                    use the price convention of the Sim object; raises an error if
+                    no pair specified at all
         :returns:   a string describing the price convention (eg "USDC per ETH")
         """
-        carbon_pair = self.get_carbon_pair(pair, tkn)
+        carbon_pair = self.get_carbon_pair(pair)
         return carbon_pair.price_convention
 
-    def _add_pos(
+    def _add_order_sell_tkn(
             self,
             tkn: str,
             amt: Any,
@@ -146,8 +172,8 @@ class CarbonSimulatorUI:
 
         :tkn:           the token that is being added to the position, eg "ETH"; it is the token being sold*
         :amt:           the amount of `tkn` that is added to the position
-        :p_lo:          the lower end of the range, quoted with `tkn` as numeraire
-        :p_hi:          ditto upper
+        :p_lo:          the lower end of the range, quoted with `tkn` as numeraire; also p_b, p_end
+        :p_hi:          ditto upper; also p_a, p_start
         :carbon_pair:   the token pair a CarbonPair object
         :id1/2:         the order ids of the two orders that make up the position; if not given, they are generated
         :returns:       the id of the order added
@@ -159,31 +185,48 @@ class CarbonSimulatorUI:
         if id2 is None:
             id2 = id1
 
-        # rearrange p_lo, p_hi if need be
-        if not p_lo <= p_hi:
-            pp = p_lo
-            p_lo = p_hi
-            p_hi = pp
-            print("WARNING: swapped start and end of the range")
+        if amt is None:
+            amt = 0
+
+        if not (p_lo is None and p_hi is None):
+
+            # check the they are both numbers
+            if p_lo is None or p_hi is None:
+                raise ValueError("p_lo, p_hi must either be both None or both numbers", p_lo, p_hi)
+
+            # rearrange p_lo, p_hi if need be
+            if not p_lo <= p_hi:
+                pp = p_lo
+                p_lo = p_hi
+                p_hi = pp
+                print("WARNING: swapped start and end of the range")
+
+            disabled = False
+
+        else:
+            disabled = True
+            p_lo = 0
+            p_hi = 0
 
         # enter order
         order_params = {
-            "tkn": tkn,  # the token being sold
-            "y_int": amt,  # the capacity of the curve
-            "_y": amt,  # the initial holding is of the curve (in `tkn`)
-            "p_low": p_lo,  # the lower end of the range (`tkn` numeraire); also p_b
-            "p_high": p_hi,  # the upper end of the range (`tkn` numeraire); also p_a
-            "pair_name": carbon_pair.pair_iso,  # the iso name of the pair
-            "pair": carbon_pair,  # the CarbonPair object
-            "id": id1,  # the id of the new curve generated
-            "linked_to_id": id2,  # the id to which this curve is linked (=id if single curve)
+            "tkn": tkn,                                 # the token being sold
+            "y_int": amt,                               # the capacity of the curve
+            "_y": amt,                                  # the initial holding is of the curve (in `tkn`)
+            "p_low": p_lo,                              # the lower end of the range (`tkn` numeraire); also p_b, p_end
+            "p_high": p_hi,                             # the upper end of the range (`tkn` numeraire); also p_a, p_start
+            "disabled": disabled,                       # if True, order is disabled (p=0)
+            "pair_name": carbon_pair.pair_iso,          # the iso name of the pair
+            "pair": carbon_pair,                        # the CarbonPair object
+            "id": id1,                                  # the id of the new curve generated
+            "linked_to_id": id2,                        # the id to which this curve is linked (=id if single curve)
         }
 
         self.orders[id1] = Order(**order_params)
         return id1
 
-    def add_sellorder(
-            self, tkn: str, amt: Any, p_start: Any, p_end: Any, pair: str = None
+    def add_order(
+            self, tkn: str, amt: Any, p_start: Any, p_end: Any, pair: Any = None
     ) -> Dict[str, Any]:
         """
         adds a sell order for tkn
@@ -197,13 +240,50 @@ class CarbonSimulatorUI:
         *p_start, p_end are interchangeable, the code deals with sorting them correctly,
         albeit with a warning message if they were in the wrong order
         """
-        try:
+        return self.add_strategy(tkn, amt, p_start, p_end, pair=pair)
 
-            # validate tkn, pair and get CarbonPair object (raises if tkn not part of pair)
-            carbon_pair = self.get_carbon_pair(pair, tkn)
+    def _add_replace_single_order(
+            self, tkn: str, amt=None, p_start=None, p_end=None, pair=None, oid=None, lid=None
+    ) -> Dict[str, Any]:
+        """
+        adds or modifies a single sell order for tkn (not part of public interface)
+
+        :tkn:           the token that is being added to the position, eg "ETH"; it is the token being sold*
+        :amt:           the amount of `tkn` that is added to the position
+        :p_start:       the start* of the range, quoted in the currency of the pair
+        :p_end:         ditto end*
+        :pair:          the token pair to which the position corresponds, eg "ETHUSD"*
+        :oid:           the id of the order; if None, a new id is created
+        :lid:           the linked order id; if None, linked to itself**
+
+        *p_start, p_end are interchangeable, the code deals with sorting them correctly,
+        albeit with a warning message if they were in the wrong order
+
+        **if orders are linked to themselves then the tokens the curve receives are not
+        stored or recorded anywhere; they simply disappear
+        """
+        try:
+            # this is a non-MVP feature
+            self._raise_if_future_restricted()
+
+            # validate tkn, pair and get CarbonPair object
+            carbon_pair = self.get_carbon_pair(pair)
+            if not carbon_pair.has_token(tkn):
+                raise ValueError("Token not part of pair", tkn, carbon_pair, pair)
 
             # create order tracking ids
-            id1 = self._posid
+            if oid is None:
+                id1 = self._posid
+                #print(f"[_add_modify_single_order] generating order with id {id1}")
+            else:
+                id1 = oid
+
+            if lid is None:
+                id2 = id1
+                #print(f"[_add_modify_single_order] setting lid to oid = {id2}")
+            else:
+                id2 = lid
+                
 
             # convert the prices from the pair numeraire to the curve numeraire
             p_start_c = carbon_pair.convert_price(p_start, tkn)
@@ -211,14 +291,14 @@ class CarbonSimulatorUI:
 
             # ugly hack, but somehow we need to switch lo and hi to have the
             # boundary closer to the money always first
-            order_id = self._add_pos(
-                tkn, amt, p_end_c, p_start_c, carbon_pair, id1, id1
+            order_id = self._add_order_sell_tkn(
+                tkn, amt, p_end_c, p_start_c, carbon_pair, id1, id2
             )
 
             if self.verbose:
                 print(
                     f"[add_sgl_pos] added position: tkn={tkn}, amt={amt}, p_start={p_start}, p_end={p_end}, "
-                    f"pair={carbon_pair.pair_iso}"
+                    f"pair={carbon_pair.pair_iso}, id={id1}, lid={id2}"
                 )
 
             orders = self._to_pandas(self.orders[order_id], decimals=self.decimals)
@@ -228,20 +308,20 @@ class CarbonSimulatorUI:
             if self.raiseonerror:
                 raise
             return {"success": False, "error": str(e), "exception": e}
-        return {"success": True, "orders": orders, "orderuis": orderuis}
+        return {"success": True, "orders": orders, "orderuis": orderuis, "id": id1, "lid": id2}
 
-    add_sgl_pos = add_sellorder
-    add_order = add_sellorder
+    #add_sgl_pos = add_sellorder
+    #add_order = add_sellorder
 
     def add_strategy(
             self,
             tkn: str,
-            amt_sell: Any,
-            psell_start: Any,
-            psell_end: Any,
-            amt_buy: Any,
-            pbuy_start: Any,
-            pbuy_end: Any,
+            amt_sell: Any = None,
+            psell_start: Any = None,
+            psell_end: Any = None,
+            amt_buy: Any = None,
+            pbuy_start: Any = None,
+            pbuy_end: Any = None,
             pair: str = None,
     ) -> Dict[str, Any]:
         """
@@ -259,12 +339,19 @@ class CarbonSimulatorUI:
         *px_start, px_end are interchangeable, the code deals with sorting them, albeit issuing a warning
         message if they are in the wrong order; sell and buy is seen from the perspective of the AMM, which
         is the same as that of the strategy (liquidity) provider
+
+        amounts that are None (default) are set to zero
+        pbuy that are None are effectively set to 0 (disabled)
+        psell that are None are effectively set to 1/0 (disabled)
         """
         try:
 
-            # validate tkn, pair and get CarbonPair object (raises if tkn not part of pair)
-            carbon_pair = self.get_carbon_pair(pair, tkn)
+            # validate tkn, pair and get CarbonPair object
+            carbon_pair = self.get_carbon_pair(pair)
             tkn2 = carbon_pair.other(tkn)
+            if tkn2 is None:
+                raise ValueError("Token not in pair", tkn, carbon_pair.slashpair, pair.slashpair)
+
 
             # create order tracking ids
             id1 = self._posid
@@ -278,10 +365,10 @@ class CarbonSimulatorUI:
 
             # ugly hack but the 1/2 range boundaries are in the wrong order
             # we want the closer boundary first
-            self._add_pos(
+            self._add_order_sell_tkn(
                 tkn, amt_sell, psell_end_c, psell_start_c, carbon_pair, id1, id2
             )
-            self._add_pos(
+            self._add_order_sell_tkn(
                 tkn2, amt_buy, pbuy_end_c, pbuy_start_c, carbon_pair, id2, id1
             )
 
@@ -309,7 +396,7 @@ class CarbonSimulatorUI:
             return {"success": False, "error": str(e), "exception": e}
         return {"success": True, "orders": orders, "orderuis": orderuis}
 
-    add_linked_pos = add_strategy
+    #add_linked_pos = add_strategy
 
     def delete_order(self, position_id):
         """
@@ -350,7 +437,7 @@ class CarbonSimulatorUI:
             [position_id, linked_position_id] if linked_position_id else [position_id]
         )
 
-    delete_pos = delete_order
+    #delete_pos = delete_order
     delete_strategy = delete_order
 
     def _trade(
@@ -403,6 +490,7 @@ class CarbonSimulatorUI:
                 if self.orders[k].pair_name
                    in [carbon_pair.pair_iso, carbon_pair_r.pair_iso]
                    and self.orders[k].tkn == tkn
+                   and not self.orders[k].disabled
                 if self.orders[k].y > 0
             ]
             use_positions = use_positions if use_positions is not None else order_ids
@@ -758,22 +846,31 @@ class CarbonSimulatorUI:
 
         orderui = CarbonOrderUI.from_order(order)
         # print("[_to_pandas]", orderui)
+
+        if order.disabled:
+            p_start = None
+            p_end = None
+        else:
+            p_start = float(order.pair.convert_price(order.p_high, order.tkn))
+            p_end   = float(order.pair.convert_price(order.p_low, order.tkn))
+
         dic = {
-            "id": order.id,
-            "pair": order.pair_name,
-            "tkn": order.tkn,
-            # "y_int": round(order.y_int, decimals),
-            # "y": round(order.y, decimals),
-            "y_int": float(order.y_int),
-            "y": float(order.y),
-            "y_unit": order.tkn,
-            # "p_start": round(order.pair.convert_price(order.p_high, order.tkn), decimals),
-            # "p_end": round(order.pair.convert_price(order.p_low, order.tkn), decimals),
-            "p_start": float(order.pair.convert_price(order.p_high, order.tkn)),
-            "p_end": float(order.pair.convert_price(order.p_low, order.tkn)),
-            "p_marg": orderui.p_marg,
-            "p_unit": order.pair.price_convention,
-            "lid": order.linked_to_id,
+            "id":           order.id,
+            "pair":         order.pair_name,
+            "tkn":          order.tkn,
+            # "y_int":      round(order.y_int, decimals),
+            # "y":          round(order.y, decimals),
+            "y_int":        float(order.y_int),
+            "y":            float(order.y),
+            "y_unit":       order.tkn,
+            # "p_start":    round(order.pair.convert_price(order.p_high, order.tkn), decimals),
+            # "p_end":      round(order.pair.convert_price(order.p_low, order.tkn), decimals),
+            "disabled":     order.disabled,
+            "p_start":      p_start,
+            "p_end":        p_end,
+            "p_marg":       orderui.p_marg,
+            "p_unit":       order.pair.price_convention,
+            "lid":          order.linked_to_id,
         }
         return pd.DataFrame(dic, index=[order.id])
 
@@ -881,7 +978,7 @@ class CarbonSimulatorUI:
         """
         PRIVATE - handles trade tkn, pair validations
         """
-        carbon_pair = self.get_carbon_pair(pair, tkn)
+        carbon_pair = self.get_carbon_pair(pair)
         return tkn, carbon_pair.other(tkn), carbon_pair
 
     def _assert_tkn_is_in_positions(self, tkn: str):
@@ -915,5 +1012,5 @@ class CarbonSimulatorUI:
         return len(self.orders)
 
     def __repr__(self):
-        pair = self._carbon_pair if self._carbon_pair else self.pair
-        return f"{self.__class__.__name__}(<{self.numpos} orders, {self.numtrades} trades>, pair='{pair}')"
+        pair = f"'{self._carbon_pair.slashpair}'" if self._carbon_pair else None
+        return f"{self.__class__.__name__}(<{self.numpos} orders, {self.numtrades} trades>, pair={pair}, mm='{self._mm}', xf={self.exclude_future})"
